# econ_layers


[![image](https://img.shields.io/pypi/v/econ_layers.svg)](https://pypi.python.org/pypi/econ_layers)

[![image](https://pyup.io/repos/github/HighDimensionalEconLab/econ_layers/shield.svg)](https://pyup.io/repos/github/HighDimensionalEconLab/econ_layers)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: MIT license
-   Documentation: https://HighDimensionalEconLab.github.io/econ_layers
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
